/* $Id */
/* general */
#define PACKAGE "gnp"
#define VERSION "x.x"

/* for runtime debugging */
#undef APP_DEBUG

/* for file locking */
#undef USE_FCNTL
#undef USE_FLOCK

/* for project/ide features (experimental) */
#undef WANT_PROJECT

/* for gnotepad+ ! */
#define APP_GNP	1
